@@ -98,18 +98,18 @@ where
         Ok(())
     }
     #[inline]
-    pub async fn send<B: Deref<Target = [u8]> + Send + Sync + 'static>(&mut self, buff: B) -> Result<usize> {
+    pub async fn send<'a>(&'a mut self, buff:  &'a [u8]) -> Result<usize> {
         if !self.disconnect {
-            Ok(self.sender.write(&buff).await?)
+            Ok(self.sender.write(buff).await?)
         } else {
             bail!("Send Error,Disconnect")
         }
     }
 
     #[inline]
-    async fn send_all<B: Deref<Target = [u8]> + Send + Sync + 'static>(&mut self, buff: B) -> Result<()>{
+    async fn send_all<'a>(&'a mut self, buff: &'a [u8]) -> Result<()>{
         if !self.disconnect {
-            Ok(self.sender.write_all(&buff).await?)
+            Ok(self.sender.write_all(buff).await?)
         } else {
             bail!("Send Error,Disconnect")
         }
@@ -129,6 +129,8 @@ where
 pub trait SocketClientTrait {
     async fn send<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<usize>;
     async fn send_all<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<()>;
+    async fn send_ref<'a>(&'a self, buff: &'a [u8]) -> Result<usize>;
+    async fn send_all_ref<'a>(&'a self, buff: &'a [u8]) -> Result<()>;
     async fn flush(&mut self) -> Result<()>;
     async fn disconnect(&self) -> Result<()>;
 }
@@ -140,15 +142,27 @@ where
 {
     #[inline]
     async fn send<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<usize> {
+        self.inner_call(async move |inner| inner.get_mut().send(&buff).await)
+            .await
+    }
+    #[inline]
+    async fn send_all<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<()> {
+        self.inner_call(async move |inner| inner.get_mut().send_all(&buff).await)
+            .await
+    }
+    #[inline]
+    async fn send_ref<'a>(&'a self, buff: &'a [u8]) -> Result<usize> {
+        ensure!(!buff.is_empty(), "send buff is null");
         unsafe {
-            self.inner_call(async move |inner| inner.get_mut().send(buff).await)
+            self.inner_call_ref(async move |inner| inner.get_mut().send(buff).await)
                 .await
         }
     }
     #[inline]
-    async fn send_all<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<()>{
+    async fn send_all_ref<'a>(&'a self, buff: &'a [u8]) -> Result<()> {
+        ensure!(!buff.is_empty(), "send buff is null");
         unsafe {
-            self.inner_call(async move |inner| inner.get_mut().send_all(buff).await)
+            self.inner_call_ref(async move |inner| inner.get_mut().send_all(buff).await)
                 .await
         }
     }
